@@ -359,12 +359,14 @@ class SparseBase(Operator):
             sizeoftuple = sys.getsizeof(())
             return (24 * m.ndim + m.dtype.itemsize +
                     2 * sizeoftuple + 24) * len(m.viewitems())
+        try:
+            return m.data.nbytes
+        except AttributeError:
+            pass
         raise TypeError("The sparse format '{0}' is not handled."
                         .format(type(m)))
 
 
-@linear
-@contiguous
 class SparseOperator(SparseBase):
     """
     Operator handling sparse matrix storages.
